@@ -79,7 +79,7 @@ class Dataset(SqlAlchemyBase, FidesBase):
 
     meta = Column(JSON)
     data_categories = Column(ARRAY(String))
-    data_qualifiers = Column(ARRAY(String))
+    data_qualifier = Column(String)
     collections = Column(JSON)
 
 
@@ -154,4 +154,5 @@ sql_model_map: Dict = {
     "policy": Policy,
     "registry": Registry,
     "system": System,
+    "evaluation": Evaluation,
 }
