@@ -3,8 +3,8 @@ import pprint
 
 import click
 
-from fidesapi.main import start_webserver
 from fidesapi import database
+from fidesapi.main import start_webserver
 from fidesctl.cli.options import (
     dry_flag,
     fides_key_argument,
@@ -22,6 +22,7 @@ from fidesctl.core import (
     apply as _apply,
     evaluate as _evaluate,
     generate_dataset as _generate_dataset,
+    annotate_dataset as _annotate_dataset,
     parse as _parse,
 )
 from fidesctl.core.utils import echo_green, echo_red
@@ -33,12 +34,15 @@ from fidesctl.core.utils import echo_green, echo_red
 @click.option(
     "--diff",
     is_flag=True,
-    help="Outputs a detailed diff of the local resource files compared to the server resources.",
+    help="Print the diff between the server's old and new states in Python DeepDiff format",
 )
 @manifests_dir_argument
 def apply(ctx: click.Context, dry: bool, diff: bool, manifests_dir: str) -> None:
     """
-    Send the manifest files to the server.
+    Update server with your local resources.
+
+    Reads the resource manifest files that are stored in MANIFESTS_DIR (and its subdirectories) and applies the resources to your server. If a named resource already exists, the resource is completely overwritten with the new description; if it doesn't exist, it's created.
+
     """
     config = ctx.obj["CONFIG"]
     taxonomy = _parse.parse(manifests_dir)
@@ -57,7 +61,13 @@ def apply(ctx: click.Context, dry: bool, diff: bool, manifests_dir: str) -> None
 @fides_key_argument
 def delete(ctx: click.Context, resource_type: str, fides_key: str) -> None:
     """
-    Delete an resource by its id.
+    Delete a specified resource.
+
+    Args:
+
+        [resource type list] (string): the type of resource from the enumeration that you want to delete
+
+        FIDES_KEY (string): the Fides key of the resource that you want to delete.
     """
     config = ctx.obj["CONFIG"]
     handle_cli_response(
@@ -77,10 +87,12 @@ def delete(ctx: click.Context, resource_type: str, fides_key: str) -> None:
     "-k",
     "--fides-key",
     default="",
-    help="The fides_key for the specific Policy to be evaluated.",
+    help="The Fides key of the single policy that you wish to evaluate. This key is a string token that uniquely identifies the policy.",
 )
 @click.option(
-    "-m", "--message", help="Description of the changes this evaluation encapsulates."
+    "-m",
+    "--message",
+    help="A message that you can supply to describe the purpose of this evaluation.",
 )
 @dry_flag
 def evaluate(
@@ -91,12 +103,10 @@ def evaluate(
     dry: bool,
 ) -> None:
     """
-    Evaluate a registry or system, either approving or denying
-    based on organizational policies.
+    Assess your data's compliance to policies.
+
+    This command will first `apply` the resources defined in MANIFESTS_DIR to your server and then assess your data's compliance to your policies or single policy.
 
-    Evaluate will always run the "apply" command before the
-    evaluation, either dry or not depending on the flag
-    passed to "evaluate".
     """
 
     config = ctx.obj["CONFIG"]
@@ -126,11 +136,13 @@ def generate_dataset(
     ctx: click.Context, connection_string: str, output_filename: str
 ) -> None:
     """
-    Generates a comprehensive dataset manifest from a database.
+    Connect a database to create a dataset.
+
+    Automatically create a dataset .yml file by directly connecting the database.
 
     Args:
 
-        connection_string (str): A SQLAlchemy-compatible connection string
+        connection_string (string): A SQLAlchemy-compatible connection string
 
         output_filename (str): A path to where the manifest will be written
     """
@@ -138,13 +150,48 @@ def generate_dataset(
     _generate_dataset.generate_dataset(connection_string, output_filename)
 
 
+@click.command()
+@click.pass_context
+@click.argument("input_filename", type=str)
+@click.option(
+    "-a",
+    "--all-members",
+    is_flag=True,
+    help="Annotate all dataset members, not just fields",
+)
+@click.option(
+    "-v", "--validate", is_flag=True, default=False, help="Validate annotation inputs"
+)
+def annotate_dataset(
+    ctx: click.Context, input_filename: str, all_members: bool, validate: bool
+) -> None:
+    """
+    Guided dataset annotation.
+
+    Read and annotate a dataset.yml file to add data_categories in a guided UI. This command edits the input file in place.
+
+    Args:
+
+        input_filename: the dataset.yml file to be read and edited
+    """
+    _annotate_dataset.annotate_dataset(
+        input_filename, annotate_all=all_members, validate=validate
+    )
+
+
 @click.command()
 @click.pass_context
 @resource_type_argument
 @fides_key_argument
 def get(ctx: click.Context, resource_type: str, fides_key: str) -> None:
     """
-    Get an resource by its id.
+    Print the resource as a JSON object.
+
+    Args:
+
+        [resource type list] (string): the type of resource from the enumeration that you want to retrieve
+
+        FIDES_KEY (string): the Fides key of the resource that you want to retrieve
     """
     config = ctx.obj["CONFIG"]
     handle_cli_response(
@@ -161,7 +208,10 @@ def get(ctx: click.Context, resource_type: str, fides_key: str) -> None:
 @click.pass_context
 def init_db(ctx: click.Context) -> None:
     """
-    Initialize or upgrade the database by running all of the existing migrations.
+    Initialize and launch your Fides policy database.
+
+    After you've initialized your database, you should add your policy resources by calling 'apply'.
+
     """
     config = ctx.obj["CONFIG"]
     database.init_db(config.api.database_url, fidesctl_config=config)
@@ -172,7 +222,13 @@ def init_db(ctx: click.Context) -> None:
 @resource_type_argument
 def ls(ctx: click.Context, resource_type: str) -> None:  # pylint: disable=invalid-name
     """
-    List all resources of a certain type.
+    List resource objects.
+
+    This command will print the JSON object for the specified resource.
+
+    Args:
+
+        [resource type list] (string): the type of resource from the enumeration that you want to retrieve
     """
     config = ctx.obj["CONFIG"]
     handle_cli_response(
@@ -190,7 +246,11 @@ def ls(ctx: click.Context, resource_type: str) -> None:  # pylint: disable=inval
 @verbose_flag
 def parse(ctx: click.Context, manifests_dir: str, verbose: bool = False) -> None:
     """
-    Parse the file(s) at the provided path into a Taxonomy and surface any validation errors.
+    Validate the taxonomy described by the manifest files.
+
+    Reads the resource files that are stored in MANIFESTS_DIR and its subdirectories to verify presence of taxonomy valuse. If the taxonomy is successfully validated, the command prints a success message and returns 0. If invalid, the command prints one or more error messages and returns non-0.
+
+    Note: No resources are applied to your server in this command. Enabling -v will print the taxonomy.
     """
 
     taxonomy = _parse.parse(manifests_dir)
@@ -202,7 +262,9 @@ def parse(ctx: click.Context, manifests_dir: str, verbose: bool = False) -> None
 @click.pass_context
 def ping(ctx: click.Context, config_path: str = "") -> None:
     """
-    Ping the Server.
+    Confirm fidesctl is running.
+
+    Sends a message to the Fides API health-check endpoint and prints the response.
     """
     config = ctx.obj["CONFIG"]
     healthcheck_url = config.cli.server_url + "/health"
@@ -215,8 +277,10 @@ def ping(ctx: click.Context, config_path: str = "") -> None:
 @yes_flag
 def reset_db(ctx: click.Context, yes: bool) -> None:
     """
-    Drops all tables and metadata from the database and
-    re-initializes the database.
+    Full database cleanse.
+
+    Removes the resources that you added through previous 'apply' calls, and then re-initializes the database by running `init-db`.
+
     """
     config = ctx.obj["CONFIG"]
     database_url = config.api.database_url
@@ -238,7 +302,9 @@ def reset_db(ctx: click.Context, yes: bool) -> None:
 @click.pass_context
 def view_config(ctx: click.Context) -> None:
     """
-    Print out the config values.
+    Prints the current fidesctl configuration. You can modify the configuration by passing a configuration file to the 'fidesctl' command:
+
+    $ fidesctl --config-path config_files
     """
     config = ctx.obj["CONFIG"]
     pretty_echo(config.dict(), color="green")
@@ -248,6 +314,6 @@ def view_config(ctx: click.Context) -> None:
 @click.pass_context
 def webserver(ctx: click.Context) -> None:
     """
-    Starts the API webserver.
+    Starts the fidesctl API server.
     """
     start_webserver()
